@@ -8,7 +8,7 @@ from six import StringIO
 
 import conans
 from conans import __version__ as client_version
-from sense2.client.cache.cache import ClientCache
+from conans.client.cache.cache import ClientCache
 from conans.client.cmd.build import cmd_build
 from conans.client.cmd.create import create
 from conans.client.cmd.download import download
@@ -18,7 +18,7 @@ from conans.client.cmd.profile import (cmd_profile_create, cmd_profile_delete_ke
                                        cmd_profile_list, cmd_profile_update)
 from conans.client.cmd.search import Search
 from conans.client.cmd.test import install_build_and_test
-from sense2.client.cmd.uploader import CmdUpload
+from conans.client.cmd.uploader import CmdUpload
 from conans.client.cmd.user import user_set, users_clean, users_list, token_present
 from conans.client.conanfile.package import run_package_method
 from conans.client.conf.required_version import check_required_conan_version
