@@ -53,8 +53,12 @@ class {package_name}Conan(Sense2File):
     }}
     changelog = "my changelog test"
     
+    ### upload cpp package to artifactory
+    # user="user"
+    # channel="beta"
+
     ## upload deb setting
-    user = "user"
+    apt_user = "qiuhai"
     apt_sever = "http://10.0.50.109:8081/repository/sense2-system-deb/"
     
     ## set source at the same folder with recipe
