@@ -4,7 +4,8 @@ import signal
 from argparse import ArgumentError
 from conans.client.command import (Command as Command_co, SmartFormatter, OnceArgument, 
                                    _PATH_HELP, _INSTALL_FOLDER_HELP, 
-                                   _SOURCE_FOLDER_HELP)
+                                   _SOURCE_FOLDER_HELP, _BUILD_FOLDER_HELP, 
+                                   _PATTERN_REF_OR_PREF_HELP, _QUERY_HELP)
 from sense2 import __version__ as client_version
 from sense2.client.sense2_api import Sense2, default_manifest_folder, _make_abs_path, ProfileData
 from conans.errors import ConanException, ConanInvalidConfiguration, NoRemoteAvailable, \
@@ -14,6 +15,8 @@ from conans.cli.exit_codes import SUCCESS, ERROR_MIGRATION, ERROR_GENERAL, USER_
 from conans.model.ref import ConanFileReference, PackageReference, get_reference_fields, \
     check_valid_ref
 from conans.client.output import Color
+from conans.client.cmd.uploader import UPLOAD_POLICY_FORCE, \
+    UPLOAD_POLICY_NO_OVERWRITE, UPLOAD_POLICY_NO_OVERWRITE_RECIPE, UPLOAD_POLICY_SKIP
 
 class Command(Command_co):
     """A single command of the conan application, with all the first level commands. Manages the
