@@ -1,5 +1,5 @@
 import os
-from conans.client.conan_api import (ConanApp as ConanApp_co, ConanAPIV1, api_method, _get_conanfile_path, 
+from conans.client.conan_api import (ConanApp as ConanApp_co, ConanAPIV1 as ConanAPIV1_co, api_method, _get_conanfile_path, 
                                     _make_abs_path, 
                                     default_manifest_folder as default_manifest_folder_co,
                                     ProfileData as ProfileData_co, get_graph_info, _parse_manifests_arguments
@@ -7,6 +7,7 @@ from conans.client.conan_api import (ConanApp as ConanApp_co, ConanAPIV1, api_me
 from conans.errors import (ConanException, RecipeNotFoundException,
                            PackageNotFoundException, NoRestV2Available, NotFoundException)
 from sense2.client.conanfile.deb import run_deb_method
+from sense2.client.cache.cache import ClientCache
 from conans.client.recorder.upload_recoder import UploadRecorder
 from sense2.client.cmd.uploader_deb import CmdUploadDeb
 from conans.client.recorder.action_recorder import ActionRecorder
@@ -29,14 +30,15 @@ class Sense2App(ConanApp_co):
     def __init__(self, cache_folder, user_io, http_requester=None, runner=None, quiet_output=None):
         super().__init__(cache_folder, user_io, http_requester, runner, quiet_output)
         
-        self.loader = ConanFileLoader(self.runner, self.out, self.python_requires,
-                                      self.generator_manager, self.pyreq_loader, self.requester)
+        self.cache = ClientCache(self.cache_folder, self.out)
+        # self.loader = ConanFileLoader(self.runner, self.out, self.python_requires,
+        #                               self.generator_manager, self.pyreq_loader, self.requester)
 
-        self.graph_manager = GraphManager(self.out, self.cache, self.remote_manager, self.loader,
-                                          self.proxy, self.range_resolver, self.binaries_analyzer)
+        # self.graph_manager = GraphManager(self.out, self.cache, self.remote_manager, self.loader,
+        #                                   self.proxy, self.range_resolver, self.binaries_analyzer)
 
 
-class Sense2APIV1(ConanAPIV1):
+class Sense2APIV1(ConanAPIV1_co):
     
     def create_app(self, quiet_output=None):
         self.app = Sense2App(self.cache_folder, self.user_io, self.http_requester,
